Module audio_device_base

Module audio_device_base 

Available on crate feature api-12 only.

Structs

OH_AudioDeviceDescriptor
Declaring the audio device descriptor. The instance is used to get more audio device detail attributes.
OH_AudioDeviceDescriptorArray
Declaring the audio device descriptor array.
OH_AudioDevice_BlockStatusapi-13
Declaring the audio device blocked status. By default, the audio device is considered as unbloked.
OH_AudioDevice_ChangeType
Defines the audio device change type.
OH_AudioDevice_Flag
Defines the audio device flag.
OH_AudioDevice_Role
Defines the audio device device role.
OH_AudioDevice_Type
Defines the audio device device type.
OH_AudioDevice_Usage
Defines the audio device usage.

Functions

OH_AudioDeviceDescriptor_GetDeviceAddress
Query the device address of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceChannelCounts
Query the device channel count array of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceDisplayName
Query the display name of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceEncodingTypes
Query the encoding type array of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceId
Query the device id of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceName
Query the device name of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceRole
Query the device role of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceSampleRates
Query the sample rate array of the target audio device descriptor.
OH_AudioDeviceDescriptor_GetDeviceType
Query the device type of the target audio device descriptor.