OH_AudioDeviceDescriptor_GetDeviceAddress

Function OH_AudioDeviceDescriptor_GetDeviceAddress 

pub unsafe extern "C" fn OH_AudioDeviceDescriptor_GetDeviceAddress(
    audioDeviceDescriptor: *mut OH_AudioDeviceDescriptor,
    address: *mut *mut c_char,
) -> OH_AudioCommon_Result
Available on crate feature api-12 only.
Query the device address of the target audio device descriptor.

Arguments

  • audioDeviceDescriptor - reference returned by [OH_AudioRoutingManager_GetDevices] or [OH_AudioRouterManager_OnDeviceChangedCallback].

  • address - pointer variable that will be set the device address value. Do not release the address pointer separately instead call [OH_AudioRoutingManager_ReleaseDevices] to release the DeviceDescriptor array when it is no use anymore.

Returns

  • [#AUDIOCOMMON_RESULT_SUCCESS] or [#AUDIOCOMMON_RESULT_ERROR_INVALID_PARAM].

Available since API-level: 12