OH_AudioResourceManager

Struct OH_AudioResourceManager 

pub struct OH_AudioResourceManager { /* private fields */ }
Available on crate feature api-20 only.
Declare the audio resource manager. Audio resource manager provides many functions for developer to manage system resources to avoid underrun or overrun in audio playback and recording.

Available since API-level: 20