OH_AudioWorkgroup

Struct OH_AudioWorkgroup 

pub struct OH_AudioWorkgroup { /* private fields */ }
Available on crate feature api-20 only.
Declare the audio workgroup. The handle of audio workgroup is used for workgroup related functions. The system will manage cpu resources on a workgroup basis instead of thread. For parallel task threads, you can add them into one workgroup, and for asynchronous task threads, use one workgroup for each thread. There is an upper limit to the total number of workgroups for each process, so application should release the workgroup which is no longer in use.

Available since API-level: 20