OH_AudioSession_StateChangeHint

Struct OH_AudioSession_StateChangeHint 

#[repr(transparent)]
pub struct OH_AudioSession_StateChangeHint(pub c_uint);
Available on crate features api-12 and api-20 only.
Declare the audio session state change hints.

Available since API-level: 20

Tuple Fields

0: c_uint

Implementations

Source

impl OH_AudioSession_StateChangeHint

pub const AUDIO_SESSION_STATE_CHANGE_HINT_RESUME: OH_AudioSession_StateChangeHint

Resume the playback

pub const AUDIO_SESSION_STATE_CHANGE_HINT_PAUSE: OH_AudioSession_StateChangeHint

paused/pause the playback

pub const AUDIO_SESSION_STATE_CHANGE_HINT_STOP: OH_AudioSession_StateChangeHint

stopped/stop the playback.

pub const AUDIO_SESSION_STATE_CHANGE_HINT_TIME_OUT_STOP: OH_AudioSession_StateChangeHint

stopped/stop the playback due to no audio stream for a long time.

pub const AUDIO_SESSION_STATE_CHANGE_HINT_DUCK: OH_AudioSession_StateChangeHint

Ducked the playback. (In ducking, the audio volume is reduced, but not silenced.)

pub const AUDIO_SESSION_STATE_CHANGE_HINT_UNDUCK: OH_AudioSession_StateChangeHint

Unducked the playback.

pub const AUDIO_SESSION_STATE_CHANGE_HINT_MUTE_SUGGESTION: OH_AudioSession_StateChangeHint

Available on crate feature api-23 only.

Suggests to mute the playback because there is another application begin to play nonmixable audio, application can decide whether to mute. If interrupt strategy is duck, [#AUDIO_SESSION_STATE_CHANGE_HINT_DUCK] will replace mute suggestion event, but application can still decide to mute when receive hint duck.

Available since API-level: 23

pub const AUDIO_SESSION_STATE_CHANGE_HINT_UNMUTE_SUGGESTION: OH_AudioSession_StateChangeHint

Available on crate feature api-23 only.

Suggest to unmute the playback because another application’s nonmixable audio ends, application can decide whether to mute. If interrupt strategy is unduck, [#AUDIO_SESSION_STATE_CHANGE_HINT_UNDUCK] will replace unmute suggestion event, but application can still decide to unmute when receive hint unduck.

Available since API-level: 23