Available on crate feature
api-19 only.Structs
- OH_
Audio Stream Manager - Declare the audio stream manager. Audio stream manager provides many functions about audio streams, like monitoring audio streams status, getting different stream types supported information and so on.
Functions
- OH_
Audio ⚠Manager_ GetAudio Stream Manager - Fetch the audio streammanager handle, which is a singleton.
- OH_
Audio ⚠Stream Manager_ GetDirect Playback Support - Gets the mode of direct playback available for a given audio format with current active device.
- OH_
Audio ⚠Stream Manager_ IsAcoustic Echo Canceler Supported api-20 - Query whether acoustic echo canceler is supported by input source.
- OH_
Audio ⚠Stream Manager_ IsFast Playback Supported api-20 - Return if fast playback is supported for the specific audio stream info and usage type in current device situation.
- OH_
Audio ⚠Stream Manager_ IsFast Recording Supported api-20 - Return if fast recording is supported for the specific audio stream info and source type in current device situation.
- OH_
Audio ⚠Stream Manager_ IsIntelligent Noise Reduction Enabled ForCurrent Device api-21 - Return if the system recording enables intelligent noise reduction for current device.