OH_AudioStreamManager

Struct OH_AudioStreamManager 

pub struct OH_AudioStreamManager { /* private fields */ }
Available on crate feature api-19 only.
Declare the audio stream manager. Audio stream manager provides many functions about audio streams, like monitoring audio streams status, getting different stream types supported information and so on.

Available since API-level: 19