#[repr(transparent)]pub struct OH_AudioStreamErrorCode(pub NonZero<c_uint>);Expand description
Define the result of the function execution.
Available since API-level: 10
Tuple Fields
0: NonZero<c_uint>Implementations
Sourceimpl OH_AudioStreamErrorCode
impl OH_AudioStreamErrorCode
Sourcepub const INVALID_PARAM: OH_AudioStreamErrorCode
pub const INVALID_PARAM: OH_AudioStreamErrorCode
This means that the function was executed with an invalid input parameter.
Available since API-level: 10
Sourcepub const ILLEGAL_STATE: OH_AudioStreamErrorCode
pub const ILLEGAL_STATE: OH_AudioStreamErrorCode
Execution status exception.
Available since API-level: 10
Sourcepub const SYSTEM: OH_AudioStreamErrorCode
pub const SYSTEM: OH_AudioStreamErrorCode
An system error has occurred.
Available since API-level: 10
Sourcepub const UNSUPPORTED_FORMAT: OH_AudioStreamErrorCode
Available on crate feature api-19 only.
pub const UNSUPPORTED_FORMAT: OH_AudioStreamErrorCode
api-19 only.Unsupported audio format, such as unsupported encoding type, sample format etc.
Available since API-level: 19