#[repr(transparent)]pub struct OH_AudioStream_VolumeMode(pub c_uint);Available on crate feature
api-19 only.Expand description
Define the audio stream volume mode.
Available since API-level: 19
Tuple Fields
0: c_uintImplementations
Sourceimpl OH_AudioStream_VolumeMode
impl OH_AudioStream_VolumeMode
Sourcepub const AUDIOSTREAM_VOLUMEMODE_SYSTEM_GLOBAL: OH_AudioStream_VolumeMode
pub const AUDIOSTREAM_VOLUMEMODE_SYSTEM_GLOBAL: OH_AudioStream_VolumeMode
Indicates this audio stream volume will be affected by system volume, also the default behavior.
Available since API-level: 19
Sourcepub const AUDIOSTREAM_VOLUMEMODE_APP_INDIVIDUAL: OH_AudioStream_VolumeMode
pub const AUDIOSTREAM_VOLUMEMODE_APP_INDIVIDUAL: OH_AudioStream_VolumeMode
Indicates this audio stream volume will be affected by app’s individual volume percentage which set by yourself using the app volume api.
Available since API-level: 19