Available on crate feature
api-12 only.Structs
- OH_
Audio Device Descriptor - Declaring the audio device descriptor. The instance is used to get more audio device detail attributes.
- OH_
Audio Device Descriptor Array - Declaring the audio device descriptor array.
- OH_
Audio Device_ Block Status api-13 - Declaring the audio device blocked status. By default, the audio device is considered as unbloked.
- OH_
Audio Device_ Change Type - Defines the audio device change type.
- OH_
Audio Device_ Flag - Defines the audio device flag.
- OH_
Audio Device_ Role - Defines the audio device device role.
- OH_
Audio Device_ Type - Defines the audio device device type.
- OH_
Audio Device_ Usage - Defines the audio device usage.
Functions
- OH_
Audio ⚠Device Descriptor_ GetDevice Address - Query the device address of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Channel Counts - Query the device channel count array of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Display Name - Query the display name of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Encoding Types - Query the encoding type array of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Id - Query the device id of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Name - Query the device name of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Role - Query the device role of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Sample Rates - Query the sample rate array of the target audio device descriptor.
- OH_
Audio ⚠Device Descriptor_ GetDevice Type - Query the device type of the target audio device descriptor.