pub unsafe extern "C" fn OH_AudioDeviceDescriptor_GetDeviceChannelCounts(
audioDeviceDescriptor: *mut OH_AudioDeviceDescriptor,
channelCounts: *mut *mut u32,
size: *mut u32,
) -> OH_AudioCommon_ResultAvailable on crate feature
api-12 only.Expand description
Query the device channel count array of the target audio device descriptor.
Arguments
-
audioDeviceDescriptor- reference returned by [OH_AudioRoutingManager_GetDevices] or [OH_AudioRouterManager_OnDeviceChangedCallback]. -
channelCounts- array pointer variable that will be set the channel count array value. Do not release the channelCounts pointer separately instead call [OH_AudioRoutingManager_ReleaseDevices] to release the DeviceDescriptor array when it is no use anymore. -
size- pointer variable that will be set the channel count size value.
Returns
- [
#AUDIOCOMMON_RESULT_SUCCESS] or [#AUDIOCOMMON_RESULT_ERROR_INVALID_PARAM].
Available since API-level: 12