Module audio_stream_manager

Module audio_stream_manager 

Available on crate feature api-19 only.

Structs

OH_AudioStreamManager
Declare the audio stream manager. Audio stream manager provides many functions about audio streams, like monitoring audio streams status, getting different stream types supported information and so on.

Functions

OH_AudioManager_GetAudioStreamManager
Fetch the audio streammanager handle, which is a singleton.
OH_AudioStreamManager_GetDirectPlaybackSupport
Gets the mode of direct playback available for a given audio format with current active device.
OH_AudioStreamManager_IsAcousticEchoCancelerSupportedapi-20
Query whether acoustic echo canceler is supported by input source.
OH_AudioStreamManager_IsFastPlaybackSupportedapi-20
Return if fast playback is supported for the specific audio stream info and usage type in current device situation.
OH_AudioStreamManager_IsFastRecordingSupportedapi-20
Return if fast recording is supported for the specific audio stream info and source type in current device situation.
OH_AudioStreamManager_IsIntelligentNoiseReductionEnabledForCurrentDeviceapi-21
Return if the system recording enables intelligent noise reduction for current device.